@@ -1,6 +1,6 @@
 """
-pycord.ext.audio
-~~~~~~~~~~~~~~~~
+pycord.audio
+~~~~~~~~~~~~
 Lavalink Module For Pycord
 
 :copyright: 2020 PythonistaGuild & 2021 Pycord
@@ -12,7 +12,6 @@ from .errors import *
 from .eqs import *
 from .events import *
 from .player import *
-from discord.ext.commands import *
 from .node import Node
 from .meta import audioMixin
 from .websocket import WebSocket
