@@ -1,6 +1,6 @@
 """
-pycord.ext.dl
-~~~~~~~~~~~~~
+pycord.dl
+~~~~~~~~~
 YouTube Video Downloader Specialized For Pycord
 
 :copyright: 2021 Pycord
